<?php
// $Id: template.php,v 1.1 2008/02/09 21:36:21 frjo Exp $

/**
 * Intercept template variables
 *
 * @param $hook
 *   The name of the theme function being executed
 * @param $vars
 *   A sequential array of variables passed to the theme function.
 */
function _phptemplate_variables($hook, $vars) {
  switch ($hook) {
    case 'page':
      drupal_add_css($vars['directory'] .'/modules.css', 'theme', 'all');
      drupal_add_css($vars['directory'] .'/blommor.css', 'theme', 'all');
      $vars['styles'] = drupal_get_css();
      break;
    case 'node':
      // Display info only on certain node types.
      if (theme_get_setting('toggle_node_info_' . $vars['node']->type)) {
        $vars['submitted'] =  t('!user - <abbr class="created" title="!microdate">!date</abbr>', array(
          '!user' => theme('username', $vars['node']),
          '!date' => format_date($vars['node']->created),
          '!microdate' => format_date($vars['node']->created,'custom', "Y-m-d\TH:i:sO")
        ));
      }
      else {
        $vars['submitted'] = '';
      }
      if (module_exists('taxonomy')) {
        $vocabs = taxonomy_get_vocabularies();
        foreach($vocabs as $vocab) {
          $tags = array();
          $terms = taxonomy_node_get_terms_by_vocabulary($vars['node']->nid, $vocab->vid);
          foreach ($terms as $term) {
            $tags['taxonomy_term_'. $term->tid] = array(
              'title' => $term->name,
              'href' => taxonomy_term_path($term),
              'attributes' => array('rel' => 'tag', 'title' => strip_tags($term->description))
            );
          }
          if ($tags) {
            $vars['tags_'. $vocab->vid] = theme('links', $tags, array('class' => 'links inline'));
          }
        }
      }
      break;

    case 'comment':
      if ($vars['submitted']) {
        $vars['submitted'] =  t('!user - <abbr class="created" title="!microdate">!date</abbr>', array(
          '!user' => theme('username', $vars['comment']),
          '!date' => format_date($vars['comment']->timestamp),
          '!microdate' => format_date($vars['comment']->timestamp,'custom', "Y-m-d\TH:i:sO")
        ));
      }
      break;
  }

  return $vars;
}

/*
 * Declare the available regions implemented by this engine.
 *
 * @return
 *    An array of regions.  The first array element will be used as the default region for themes.
 *    Each array element takes the format: variable_name => t('human readable name')
 */
function blommor01_regions() {
  return array(
       'left' => t('left sidebar'),
       'right' => t('right sidebar'),
       'content_top' => t('content top'),
       'content_bottom' => t('content bottom'),
       'header' => t('header'),
       'footer' => t('footer')
  );
}
